models/passkey_login_request library

Classes

LoginExtensions
Optional WebAuthn client extensions for a login request.
PasskeyLoginAllowCredentialType
A credential descriptor allowed for a passkey login.
PasskeyLoginPublicKey
Public key credential request options for a passkey login.
PasskeyLoginRequest
Request payload sent to the Web SDK to authenticate with a passkey.

Enums

AuthenticatorTransport
The transports an authenticator can use to communicate.
PasskeyLoginMediationType
The mediation requirement controlling how the browser prompts the user.
UserVerificationRequirement
The relying party's requirement for user verification during an operation.