PasskeyLoginRequest class

Request payload sent to the Web SDK to authenticate with a passkey.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

PasskeyLoginRequest(PasskeyLoginPublicKey publicKey, PasskeyLoginMediationType mediation)
Creates a request from a publicKey and a mediation preference.
PasskeyLoginRequest.fromJson(Map<String, dynamic> json)
Creates a request from a decoded JSON map.
factory
PasskeyLoginRequest.fromPlatformType(String relyingPartyId, String challenge, int? timeout, String? platformUserVerification, List<CredentialType>? platformAllowCredentials, MediationType platformMediation)
Builds a request from the platform interface authentication parameters.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mediation PasskeyLoginMediationType
The mediation requirement for this authentication.
final
publicKey PasskeyLoginPublicKey
The public key credential request options.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this request to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited