PasskeySignUpRequest class
Request payload sent to the Web SDK to register a new passkey.
- Annotations
-
- @JsonSerializable.new(createFactory: false, explicitToJson: true)
Constructors
- PasskeySignUpRequest(PublicKey publicKey)
-
Creates a request from the public key credential creation
publicKey.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes this request to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited