PublicKey class
Public key credential creation options for a passkey registration.
- Annotations
-
- @JsonSerializable.new(createFactory: false, explicitToJson: true)
Constructors
Properties
- attestation → String?
-
The attestation conveyance preference.
final
- authenticatorSelection → AuthenticatorSelectionType?
-
The authenticator selection criteria.
final
- challenge → String
-
The server-generated challenge to be signed.
final
-
excludeCredentials
→ List<
CredentialType> -
Credentials that must be excluded to avoid duplicate registrations.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pubKeyCredParams
→ List<
PubKeyCredParamType> -
The credential parameters the relying party supports.
final
- rp → RelyingPartyType
-
The relying party the credential is being created for.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → int?
-
The time in milliseconds the caller is willing to wait for the operation.
final
- user → UserType
-
The user the credential is being created for.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes these options to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited