excludeCredentials property
Credentials that must be excluded to avoid duplicate registrations.
Implementation
final List<CredentialType> excludeCredentials;
Credentials that must be excluded to avoid duplicate registrations.
final List<CredentialType> excludeCredentials;