PasskeySignUpResponse class
Response returned by the Web SDK after a successful passkey registration.
- Annotations
-
- @JsonSerializable.new()
Constructors
- PasskeySignUpResponse(String id, String rawId, AttestationResponse response)
-
Creates a response from its
id,rawIdand attestationresponse. -
PasskeySignUpResponse.fromJson(Map<
String, dynamic> json) -
Creates a response from a decoded JSON map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The base64url encoded credential identifier.
final
- rawId → String
-
The raw credential identifier.
final
- response → AttestationResponse
-
The authenticator attestation response.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes this response to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited